# Blind Ingest Test — Ground Truth

10 random PDFs from compyCrystal/tome/pdf/, ingested without bib info.
Compare ingest proposals against these known-good entries.

| # | Current Key | Title | Author | Year | DOI |
|---|-------------|-------|--------|------|-----|
| 1 | loudet2007 | BODIPY Dyes and Their Derivatives: Syntheses and Spectroscopic Properties | Loudet, Aurore; Burgess, Kevin | 2007 | 10.1021/cr078381n |
| 2 | tinti2017 | Intrusion and Extrusion of Water in Hydrophobic Nanopores | Tinti, Antonio et al. | 2017 | 10.1073/pnas.1714796114 |
| 3 | grenev2022 | In Silico Screening of Metal-Organic Frameworks and Zeolites... | Grenev, Ivan V.; Gavrilov, Vladimir Yu. | 2022 | 10.3390/molecules28010020 |
| 4 | megiatto2012 | Topological and Conformational Effects on Electron Transfer... | Megiatto, Jackson D. et al. | 2012 | 10.1021/CM3004408 |
| 5 | vishay_vlmu3510 | VLMU3510-365-130 UV LED Datasheet | Vishay Semiconductors | 2024 | none |
| 6 | li2021 | Reversible Switching of Molecular Conductance in Viologens... | Li, Jialing et al. | 2021 | 10.1021/acs.jpcc.1c06942 |
| 7 | barachevsky2012 | Properties of Photochromic Retinals | Barachevsky, V.A. et al. | 2012 | 10.1016/j.dyepig.2011.05.009 |
| 8 | collier1999 | Electronically Configurable Molecular-Based Logic Gates | Collier, C. P. et al. | 1999 | 10.1126/science.285.5426.391 |
| 9 | lindahl1972 | Rate of Depurination of Native Deoxyribonucleic Acid | Lindahl, Tomas; Nyberg, Barbro | 1972 | 10.1021/bi00769a018 |
| 10 | han2023 | Oriented Attachment Interfaces of Zeolitic Imidazolate Framework Nanocrystals | Han, Xiaocang et al. | 2023 | 10.1039/D3NR00702B |
